@@ -284,10 +284,6 @@
         <source>Quality</source>
         <translation>Laatu</translation>
     </message>
-    <message>
-        <source>Scale</source>
-        <translation>Skaalaa</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Älä tallenna hiiren osoitinta</translation>
